@@ -56,10 +56,12 @@ pub(super) fn fetch_spot_markets() -> Result<Vec<Market>> {
                 exchange: "binance".to_string(),
                 market_type: MarketType::Spot,
                 symbol: m.symbol.clone(),
-                base: m.baseAsset.clone(),
-                quote: m.quoteAsset.clone(),
                 base_id: m.baseAsset.clone(),
                 quote_id: m.quoteAsset.clone(),
+                settle_id: None,
+                base: m.baseAsset.clone(),
+                quote: m.quoteAsset.clone(),
+                settle: None,
                 active: m.status == "TRADING" && m.isSpotTradingAllowed,
                 margin: m.isMarginTradingAllowed,
                 // see https://www.binance.com/en/fee/trading
