@@ -13,7 +13,7 @@ pub(crate) fn fetch_symbols(market_type: MarketType) -> Result<Vec<String>> {
         MarketType::InverseFuture => binance_inverse::fetch_inverse_future_symbols(),
         MarketType::LinearSwap => binance_linear::fetch_linear_swap_symbols(),
         MarketType::InverseSwap => binance_inverse::fetch_inverse_swap_symbols(),
-        MarketType::Option => binance_option::fetch_option_symbols(),
+        MarketType::EuropeanOption => binance_option::fetch_option_symbols(),
         _ => panic!("Unsupported market_type: {}", market_type),
     }
 }
@@ -25,7 +25,7 @@ pub(crate) fn fetch_markets(market_type: MarketType) -> Result<Vec<Market>> {
         MarketType::InverseFuture => binance_inverse::fetch_inverse_future_markets(),
         MarketType::LinearSwap => binance_linear::fetch_linear_swap_markets(),
         MarketType::InverseSwap => binance_inverse::fetch_inverse_swap_markets(),
-        MarketType::Option => binance_option::fetch_option_markets(),
+        MarketType::EuropeanOption => binance_option::fetch_option_markets(),
         _ => panic!("Unsupported market_type: {}", market_type),
     }
 }
