@@ -9,6 +9,9 @@ pub(crate) fn fetch_symbols(market_type: MarketType) -> Result<Vec<String>> {
     }
 }
 
-pub(crate) fn fetch_markets(_market_type: MarketType) -> Result<Vec<Market>> {
-    Ok(Vec::new())
+pub(crate) fn fetch_markets(market_type: MarketType) -> Result<Vec<Market>> {
+    match market_type {
+        MarketType::LinearSwap => dydx_swap::fetch_linear_swap_markets(),
+        _ => panic!("dydX does NOT have the {} market", market_type),
+    }
 }
