@@ -1,4 +1,6 @@
-use crypto_markets::{fetch_markets, fetch_symbols, get_market_types, MarketType};
+use crypto_market_type::{get_market_types, MarketType};
+use crypto_markets::{fetch_markets, fetch_symbols};
+use crypto_pair::get_market_type;
 use test_case::test_case;
 
 #[macro_use]
@@ -18,6 +20,10 @@ fn fetch_linear_swap_symbols() {
 
     for symbol in symbols.iter() {
         assert!(symbol.ends_with("-USD"));
+        assert_eq!(
+            MarketType::LinearSwap,
+            get_market_type(symbol, EXCHANGE_NAME, None)
+        );
     }
 }
 
